Built-in terminal step that marks a workflow as complete.
Always returns {:ok, :done}. Every workflow must have at least one
path leading to a Done step.
Built-in terminal step that marks a workflow as complete.
Always returns {:ok, :done}. Every workflow must have at least one
path leading to a Done step.